@@ -53,7 +53,13 @@ class McdXmlParser:
         session_name = os.path.splitext(session_name)[0]
 
         session_id = str(uuid.uuid4())
-        session = Session(session_id, session_name, __version__, datetime.now(timezone.utc), metadata=self.metadata,)
+        session = Session(
+            session_id,
+            session_name,
+            __version__,
+            datetime.now(timezone.utc),
+            metadata=self.metadata,
+        )
         for s in self.metadata.get(const.SLIDE):
             has_slide_image = (int(s.get(const.IMAGE_END_OFFSET, 0)) - int(s.get(const.IMAGE_START_OFFSET, 0))) > 0
             slide = Slide(
